@@ -13,20 +13,18 @@ use std::time::{Duration, SystemTime};
 use time;
 
 use indexmap::IndexMap;
-use log::{debug, error, info, warn};
 use ping::ping;
 use reqwest::blocking::Client;
 use reqwest::header::{HeaderMap, USER_AGENT};
 use reqwest::redirect::Policy as RedirectPolicy;
 use reqwest::StatusCode;
 use run_script::{self, ScriptOptions};
-use serde_derive::Deserialize;
 
 use super::replica::ReplicaURL;
 use super::states::{
-    ServiceStates, ServiceStatesProbe, ServiceStatesProbeNode, ServiceStatesProbeNodeRabbitMQ,
-    ServiceStatesProbeNodeReplica, ServiceStatesProbeNodeReplicaMetrics,
-    ServiceStatesProbeNodeReplicaMetricsRabbitMQ,
+    ServiceStates, ServiceStatesNotifier, ServiceStatesProbe, ServiceStatesProbeNode,
+    ServiceStatesProbeNodeRabbitMQ, ServiceStatesProbeNodeReplica,
+    ServiceStatesProbeNodeReplicaMetrics, ServiceStatesProbeNodeReplicaMetricsRabbitMQ,
 };
 use super::status::Status;
 use crate::config::config::{ConfigPluginsRabbitMQ, ConfigProbeServiceNodeHTTPMethod};
@@ -38,12 +36,15 @@ use crate::APP_CONF;
 const PROBE_HOLD_MILLISECONDS: u64 = 250;
 const PROBE_ICMP_TIMEOUT_SECONDS: u64 = 1;
 
-lazy_static::lazy_static! {
+lazy_static! {
     pub static ref STORE: Arc<RwLock<Store>> = Arc::new(RwLock::new(Store {
         states: ServiceStates {
             status: Status::Healthy,
             date: None,
             probes: IndexMap::new(),
+            notifier: ServiceStatesNotifier {
+                reminder_backoff_counter: 1,
+            }
         },
         notified: None,
     }));
